==> dvdstyler_2.3.4.orig.tar.bz2: DVDStyler-2.3.4/src/Authors.h <==
// used in src/About.cpp, encoding=UTF8
const wxString s_author = wxT("Alex Th&uuml;ring <alex at thuering.biz>");
const wxString s_docWriter = wxT("Don Brett <dlbrett at zoominternet.net>");
const wxString s_packager = wxT("Fabrice Coutadeur <coutadeurf at gmail.com>");
const wxString s_translations[][2] = {
	{ wxT("Arabic"), wxT("Awadh Alghaamdi <awadh_al_ghaamdi at hotmail.com>") },
	{ wxT("Armenian"), wxT("Hrant Ohanyan <hrantohanyan at mail.am>") },
	{ wxT("Catalan"), wxT("Rafael Ferran i Peralta <rferran at terra.es>") },
	{ wxT("Chinese (Simplified)"), wxString(wxT("程序民工 <lyj8063 at sohu.com>, 郁晓旭 <yuxiaoxu at msn.com>"), wxConvUTF8) },
	{ wxT("Chinese (Traditional)"), wxString(wxT("紀明村 <tw.chi.ming at gmail.com>, Sophina Liu <Sophina-liu at hotmail.com>"), wxConvUTF8) },
	{ wxT("Basque"), wxT("Piarres Beobide <pi at beobide.net>") },
	{ wxT("Czech"), wxString(wxT("Vlastimil Skácel <vlastiks at gmail.com>"), wxConvUTF8) },
	{ wxT("Danish"), wxT("Jørgen Rasmussen <l10n at joergenr.dk>") },
	{ wxT("Dutch"), wxT("Frank Meijer <fajmmeijer at hotmail.com>, Maikel Egberink <maikel.egberink at gmail.com>") },
	{ wxT("French"), wxT("Pierre Buard <pierre.buard at gmail.com>, R. Berzolla <rberzolla at free.fr>") },
	{ wxT("German"), wxT("Alex Th&uuml;ring <alex at thuering.biz>") },
	{ wxT("Greek"), wxT("Aristotelis Pitaridis <pitaridis at gmail.com>") },
	{ wxT("Hungarian"), wxString(wxT("Fáczán László <faczan at freemail.hu>"), wxConvUTF8) },
	{ wxT("Italian"), wxT("Marco Ciampa <ciampix at libero.it>, Alessio Leonarduzzi <alessio.leonarduzzi at gmail.com>") },
	{ wxT("Japanese"), wxT("OKANO Takayoshi <kano at na.rim.or.jp>") },
	{ wxT("Korean"), wxString(wxT("김프사랑 <yongdoria at gmail.com>"), wxConvUTF8) },
	{ wxT("Macedonian"), wxT("Damjan Dimitrioski <damjandimitrioski at gmail.com>") },
	{ wxT("Norwegian"), wxString(wxT("Olav Inge Frøynes <olavinge at gmail.com>"), wxConvUTF8) },
	{ wxT("Polish"), wxString(wxT("Michał Trzebiatowski <hippie_1968 at hotmail.com>"), wxConvUTF8) },
	{ wxT("Portuguese"), wxString(wxT("João Frade / / 100 NOME PT <100nome.portugal at gmail.com>"), wxConvUTF8) },
	{ wxT("Portuguese (Brazilian)"), wxT("Paulo Henrique Araújo <paulohenriqueyer at hotmail.com>, Igor Ruckert <igorruckert at yahoo.com.br>") },
	{ wxT("Romanian"), wxT("Dan Ibanescu <ibanescu.dan at gmail.com>") },
	{ wxT("Russian"), wxT("Alex Th&uuml;ring <alex at thuering.biz>") },
	{ wxT("Slovenian"), wxT("Martin Srebotnjak <miles at filmsi.net>") },
	{ wxT("Serbian"), wxT("CICIC Ivana <ozzii23 at gmail.com>") },
	{ wxT("Slovak"), wxT("Michal Kovac <deadsock at deadsock.co.uk>") },
	{ wxT("Spanish"), wxT("Redy Rodriguez <redy at telefonica.net>, Fabrice Coutadeur <coutadeurf at gmail.com>") },
	{ wxT("Swedish"), wxT("Daniel Nylander <po at danielnylander.se>, Tobias Holm <dvdstyler at eftprod.com>") },
	{ wxT("Turkish"), wxT("Dursun Cemal <cmldrs at yandex.com>") },
	{ wxT("Ukrainian"), wxT("Федір Зінчук <getthesite at gmail.com>") },
	{ wxT("Uzbek"), wxT("Umidjon Almasov <u.almasov at gmail.com>") },
	{ wxT("Vietnamese"), wxT("Phan Anh <ppanhh at gmail.com>") },
};

==> dvdstyler_2.5.2.orig.tar.bz2: DVDStyler-2.5.2/src/Authors.h <==
// used in src/About.cpp, encoding=UTF8
const wxString s_author = wxT("Alex Th&uuml;ring <alex at thuering.biz>");
const wxString s_docWriter = wxT("Don Brett <dlbrett at zoominternet.net>");
const wxString s_packager = wxT("Fabrice Coutadeur <coutadeurf at gmail.com>");
const wxString s_translations[][2] = {
	{ wxT("Arabic"), wxT("Awadh Alghaamdi <awadh_al_ghaamdi at hotmail.com>") },
	{ wxT("Armenian"), wxT("Hrant Ohanyan <hrantohanyan at mail.am>") },
	{ wxT("Catalan"), wxT("Rafael Ferran i Peralta <rferranp at gmail.com>") },
	{ wxT("Chinese (Simplified)"), wxString(wxT("程序民工 <lyj8063 at sohu.com>, 郁晓旭 <yuxiaoxu at msn.com>"), wxConvUTF8) },
	{ wxT("Chinese (Traditional)"), wxString(wxT("紀明村 <tw.chi.ming at gmail.com>, Sophina Liu <Sophina-liu at hotmail.com>"), wxConvUTF8) },
	{ wxT("Basque"), wxT("Piarres Beobide <pi at beobide.net>") },
	{ wxT("Czech"), wxString(wxT("Vlastimil Skácel <vlastiks at gmail.com>"), wxConvUTF8) },
	{ wxT("Danish"), wxT("Jørgen Rasmussen <l10n at joergenr.dk>") },
	{ wxT("Dutch"), wxT("Frank Meijer <fajmmeijer at hotmail.com>, Maikel Egberink <maikel.egberink at gmail.com>") },
	{ wxT("Finnish"), wxString(wxT("Matti Leppälä <matti.leppala at wlanmail.com>"), wxConvUTF8) },
	{ wxT("French"), wxT("Cyrille Pontvieux <jrd at enialis.net>, R. Berzolla <rberzolla at free.fr>") },
	{ wxT("German"), wxT("Alex Th&uuml;ring <alex at thuering.biz>") },
	{ wxT("Greek"), wxT("Aristotelis Pitaridis <pitaridis at gmail.com>") },
	{ wxT("Hungarian"), wxString(wxT("Demecs Gábor <gabohw at freemail.hu>, Fáczán László <faczan at freemail.hu>"), wxConvUTF8) },
	{ wxT("Italian"), wxT("Marco Ciampa <ciampix at libero.it>, Alessio Leonarduzzi <alessio.leonarduzzi at gmail.com>") },
	{ wxT("Japanese"), wxT("OKANO Takayoshi <kano at na.rim.or.jp>") },
	{ wxT("Korean"), wxString(wxT("김프사랑 <yongdoria at gmail.com>"), wxConvUTF8) },
	{ wxT("Macedonian"), wxT("Damjan Dimitrioski <damjandimitrioski at gmail.com>") },
	{ wxT("Norwegian"), wxString(wxT("Olav Inge Frøynes <olavinge at gmail.com>"), wxConvUTF8) },
	{ wxT("Polish"), wxString(wxT("Michał Trzebiatowski <hippie_1968 at hotmail.com>"), wxConvUTF8) },
	{ wxT("Portuguese"), wxString(wxT("João Frade / / 100 NOME PT <100nome.portugal at gmail.com>"), wxConvUTF8) },
	{ wxT("Portuguese (Brazilian)"), wxT("SKYFORGE <skyforge at hotmail.com.br>, Paulo Henrique Araújo <paulohenriqueyer at hotmail.com>") },
	{ wxT("Romanian"), wxT("Dan Ibanescu <ibanescu.dan at gmail.com>") },
	{ wxT("Russian"), wxT("Alex Th&uuml;ring <alex at thuering.biz>") },
	{ wxT("Slovenian"), wxT("Martin Srebotnjak <miles at filmsi.net>") },
	{ wxT("Serbian"), wxT("CICIC Ivana <ozzii23 at gmail.com>") },
	{ wxT("Slovak"), wxT("Maritn Kubánik <martin.kubanik at gmail.com>, Michal Kovac <deadsock at deadsock.co.uk>") },
	{ wxT("Spanish"), wxT("Redy Rodriguez <redy at telefonica.net>, Fabrice Coutadeur <coutadeurf at gmail.com>") },
	{ wxT("Spanish (Argentina)"), wxT("Eduardo Quinteros <eduardo.j.quinteros at gmail.com>") },
	{ wxT("Swedish"), wxT("Daniel Nylander <po at danielnylander.se>, Tobias Holm <dvdstyler at eftprod.com>") },
	{ wxT("Turkish"), wxT("Dursun Cemal <cmldrs at yandex.com>") },
	{ wxT("Ukrainian"), wxT("Федір Зінчук <getthesite at gmail.com>") },
	{ wxT("Uzbek"), wxT("Umidjon Almasov <u.almasov at gmail.com>") },
	{ wxT("Vietnamese"), wxT("Phan Anh <ppanhh at gmail.com>") },
};
